import {select,csv,scaleLinear,max,scaleBand,axisLeft,axisBottom,format} from 'd3';

const titleText = 'Top 10 Most Populous Countries';
const xAxisLabelText = 'Population';
const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');
const render = data => {
  const xValue = d => d['population'];
  const yValue = d => d.country;
  const margin = { top: 160, right: 40, bottom: 57, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerHeight]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerWidth])
    .padding(.5);
	const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.bottom})`);
  const yAxisTickFormat = number =>
    format('.3s')(number)
      .replace('G', 'B');
  const yAxis = axisLeft(xScale)
    .tickFormat(yAxisTickFormat)
    .tickSize(-innerHeight);
  g.append('g')
    .call(axisBottom(yScale))
    .selectAll('.domain, .tick line')
    .remove();
  const yAxisG = g.append('g').call(yAxis)
    .attr('transform', `translate(0,${innerHeight-200})`);
  yAxisG.select('.domain').remove();
  yAxisG.append('text')
    .attr('class','axis-label')
    .attr('x', 70)
    .attr('y', innerHeight+70)
    .attr('fill', 'black')
    .text(xAxisLabelText);
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('x',d => xScale(xValue(d)))
      .attr('width',d => xScale(xScale(d)))
      .attr('height',yScale.bandwidth()) ;
  g.append('text')
      .attr('class', 'title')
      .attr('y', 0)
      .text(titleText);
};
csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population *1000 ;
  });
  render(data);
});